# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from .stats import (
    StatsResource,
    AsyncStatsResource,
    StatsResourceWithRawResponse,
    AsyncStatsResourceWithRawResponse,
    StatsResourceWithStreamingResponse,
    AsyncStatsResourceWithStreamingResponse,
)
from .top100 import (
    Top100Resource,
    AsyncTop100Resource,
    Top100ResourceWithRawResponse,
    AsyncTop100ResourceWithRawResponse,
    Top100ResourceWithStreamingResponse,
    AsyncTop100ResourceWithStreamingResponse,
)
from ..._compat import cached_property
from .checklist import (
    ChecklistResource,
    AsyncChecklistResource,
    ChecklistResourceWithRawResponse,
    AsyncChecklistResourceWithRawResponse,
    ChecklistResourceWithStreamingResponse,
    AsyncChecklistResourceWithStreamingResponse,
)
from ..._resource import SyncAPIResource, AsyncAPIResource
from .lists.lists import (
    ListsResource,
    AsyncListsResource,
    ListsResourceWithRawResponse,
    AsyncListsResourceWithRawResponse,
    ListsResourceWithStreamingResponse,
    AsyncListsResourceWithStreamingResponse,
)
from .species_list import (
    SpeciesListResource,
    AsyncSpeciesListResource,
    SpeciesListResourceWithRawResponse,
    AsyncSpeciesListResourceWithRawResponse,
    SpeciesListResourceWithStreamingResponse,
    AsyncSpeciesListResourceWithStreamingResponse,
)

__all__ = ["ProductResource", "AsyncProductResource"]


class ProductResource(SyncAPIResource):
    @cached_property
    def lists(self) -> ListsResource:
        return ListsResource(self._client)

    @cached_property
    def top100(self) -> Top100Resource:
        return Top100Resource(self._client)

    @cached_property
    def stats(self) -> StatsResource:
        return StatsResource(self._client)

    @cached_property
    def species_list(self) -> SpeciesListResource:
        return SpeciesListResource(self._client)

    @cached_property
    def checklist(self) -> ChecklistResource:
        return ChecklistResource(self._client)

    @cached_property
    def with_raw_response(self) -> ProductResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/phoebe-bird/phoebe-python#accessing-raw-response-data-eg-headers
        """
        return ProductResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> ProductResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/phoebe-bird/phoebe-python#with_streaming_response
        """
        return ProductResourceWithStreamingResponse(self)


class AsyncProductResource(AsyncAPIResource):
    @cached_property
    def lists(self) -> AsyncListsResource:
        return AsyncListsResource(self._client)

    @cached_property
    def top100(self) -> AsyncTop100Resource:
        return AsyncTop100Resource(self._client)

    @cached_property
    def stats(self) -> AsyncStatsResource:
        return AsyncStatsResource(self._client)

    @cached_property
    def species_list(self) -> AsyncSpeciesListResource:
        return AsyncSpeciesListResource(self._client)

    @cached_property
    def checklist(self) -> AsyncChecklistResource:
        return AsyncChecklistResource(self._client)

    @cached_property
    def with_raw_response(self) -> AsyncProductResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/phoebe-bird/phoebe-python#accessing-raw-response-data-eg-headers
        """
        return AsyncProductResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncProductResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/phoebe-bird/phoebe-python#with_streaming_response
        """
        return AsyncProductResourceWithStreamingResponse(self)


class ProductResourceWithRawResponse:
    def __init__(self, product: ProductResource) -> None:
        self._product = product

    @cached_property
    def lists(self) -> ListsResourceWithRawResponse:
        return ListsResourceWithRawResponse(self._product.lists)

    @cached_property
    def top100(self) -> Top100ResourceWithRawResponse:
        return Top100ResourceWithRawResponse(self._product.top100)

    @cached_property
    def stats(self) -> StatsResourceWithRawResponse:
        return StatsResourceWithRawResponse(self._product.stats)

    @cached_property
    def species_list(self) -> SpeciesListResourceWithRawResponse:
        return SpeciesListResourceWithRawResponse(self._product.species_list)

    @cached_property
    def checklist(self) -> ChecklistResourceWithRawResponse:
        return ChecklistResourceWithRawResponse(self._product.checklist)


class AsyncProductResourceWithRawResponse:
    def __init__(self, product: AsyncProductResource) -> None:
        self._product = product

    @cached_property
    def lists(self) -> AsyncListsResourceWithRawResponse:
        return AsyncListsResourceWithRawResponse(self._product.lists)

    @cached_property
    def top100(self) -> AsyncTop100ResourceWithRawResponse:
        return AsyncTop100ResourceWithRawResponse(self._product.top100)

    @cached_property
    def stats(self) -> AsyncStatsResourceWithRawResponse:
        return AsyncStatsResourceWithRawResponse(self._product.stats)

    @cached_property
    def species_list(self) -> AsyncSpeciesListResourceWithRawResponse:
        return AsyncSpeciesListResourceWithRawResponse(self._product.species_list)

    @cached_property
    def checklist(self) -> AsyncChecklistResourceWithRawResponse:
        return AsyncChecklistResourceWithRawResponse(self._product.checklist)


class ProductResourceWithStreamingResponse:
    def __init__(self, product: ProductResource) -> None:
        self._product = product

    @cached_property
    def lists(self) -> ListsResourceWithStreamingResponse:
        return ListsResourceWithStreamingResponse(self._product.lists)

    @cached_property
    def top100(self) -> Top100ResourceWithStreamingResponse:
        return Top100ResourceWithStreamingResponse(self._product.top100)

    @cached_property
    def stats(self) -> StatsResourceWithStreamingResponse:
        return StatsResourceWithStreamingResponse(self._product.stats)

    @cached_property
    def species_list(self) -> SpeciesListResourceWithStreamingResponse:
        return SpeciesListResourceWithStreamingResponse(self._product.species_list)

    @cached_property
    def checklist(self) -> ChecklistResourceWithStreamingResponse:
        return ChecklistResourceWithStreamingResponse(self._product.checklist)


class AsyncProductResourceWithStreamingResponse:
    def __init__(self, product: AsyncProductResource) -> None:
        self._product = product

    @cached_property
    def lists(self) -> AsyncListsResourceWithStreamingResponse:
        return AsyncListsResourceWithStreamingResponse(self._product.lists)

    @cached_property
    def top100(self) -> AsyncTop100ResourceWithStreamingResponse:
        return AsyncTop100ResourceWithStreamingResponse(self._product.top100)

    @cached_property
    def stats(self) -> AsyncStatsResourceWithStreamingResponse:
        return AsyncStatsResourceWithStreamingResponse(self._product.stats)

    @cached_property
    def species_list(self) -> AsyncSpeciesListResourceWithStreamingResponse:
        return AsyncSpeciesListResourceWithStreamingResponse(self._product.species_list)

    @cached_property
    def checklist(self) -> AsyncChecklistResourceWithStreamingResponse:
        return AsyncChecklistResourceWithStreamingResponse(self._product.checklist)



import os

from phoebe_bird import Phoebe

client = Phoebe(
    api_key=os.environ.get("EBIRD_API_KEY"),
)


def ref() -> None:
    hotspot = client.ref.hotspot.info.retrieve("L99381")
    print(hotspot)

    speciesGroups = client.ref.taxonomy.species_groups.list("ebird")
    print(speciesGroups)

    locales = client.ref.taxonomy.locales.list()
    print(locales)


ref()



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional

from pydantic import Field as FieldInfo

from ...._models import BaseModel

__all__ = ["InfoRetrieveResponse", "Bounds"]


class Bounds(BaseModel):
    max_x: Optional[float] = FieldInfo(alias="maxX", default=None)

    max_y: Optional[float] = FieldInfo(alias="maxY", default=None)

    min_x: Optional[float] = FieldInfo(alias="minX", default=None)

    min_y: Optional[float] = FieldInfo(alias="minY", default=None)


class InfoRetrieveResponse(BaseModel):
    bounds: Optional[Bounds] = None

    result: Optional[str] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from .hotspot_list_params import HotspotListParams as HotspotListParams
from .hotspot_list_response import HotspotListResponse as HotspotListResponse



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from .specie_list_params import SpecieListParams as SpecieListParams
from .notable_list_params import NotableListParams as NotableListParams
from .specie_list_response import SpecieListResponse as SpecieListResponse
from .notable_list_response import NotableListResponse as NotableListResponse



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import List
from typing_extensions import Literal

import httpx

from .notable import (
    NotableResource,
    AsyncNotableResource,
    NotableResourceWithRawResponse,
    AsyncNotableResourceWithRawResponse,
    NotableResourceWithStreamingResponse,
    AsyncNotableResourceWithStreamingResponse,
)
from .species import (
    SpeciesResource,
    AsyncSpeciesResource,
    SpeciesResourceWithRawResponse,
    AsyncSpeciesResourceWithRawResponse,
    SpeciesResourceWithStreamingResponse,
    AsyncSpeciesResourceWithStreamingResponse,
)
from .historic import (
    HistoricResource,
    AsyncHistoricResource,
    HistoricResourceWithRawResponse,
    AsyncHistoricResourceWithRawResponse,
    HistoricResourceWithStreamingResponse,
    AsyncHistoricResourceWithStreamingResponse,
)
from ....._types import NOT_GIVEN, Body, Query, Headers, NotGiven
from ....._utils import maybe_transform, async_maybe_transform
from ....._compat import cached_property
from ....._resource import SyncAPIResource, AsyncAPIResource
from ....._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from ....._base_client import make_request_options
from .....types.data.observations import recent_list_params
from .....types.data.observations.recent_list_response import RecentListResponse

__all__ = ["RecentResource", "AsyncRecentResource"]


class RecentResource(SyncAPIResource):
    @cached_property
    def notable(self) -> NotableResource:
        return NotableResource(self._client)

    @cached_property
    def species(self) -> SpeciesResource:
        return SpeciesResource(self._client)

    @cached_property
    def historic(self) -> HistoricResource:
        return HistoricResource(self._client)

    @cached_property
    def with_raw_response(self) -> RecentResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/phoebe-bird/phoebe-python#accessing-raw-response-data-eg-headers
        """
        return RecentResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> RecentResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/phoebe-bird/phoebe-python#with_streaming_response
        """
        return RecentResourceWithStreamingResponse(self)

    def list(
        self,
        region_code: str,
        *,
        back: int | NotGiven = NOT_GIVEN,
        cat: Literal["species", "slash", "issf", "spuh", "hybrid", "domestic", "form", "intergrade"]
        | NotGiven = NOT_GIVEN,
        hotspot: bool | NotGiven = NOT_GIVEN,
        include_provisional: bool | NotGiven = NOT_GIVEN,
        max_results: int | NotGiven = NOT_GIVEN,
        r: List[str] | NotGiven = NOT_GIVEN,
        spp_locale: str | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> RecentListResponse:
        """
        Get the list of recent observations (up to 30 days ago) of birds seen in a
        country, state, county, or location. Results include only the most recent
        observation for each species in the region specified.

        Args:
          back: The number of days back to fetch observations.

          cat: Only fetch observations from these taxonomic categories

          hotspot: Only fetch observations from hotspots

          include_provisional: Include observations which have not yet been reviewed

          max_results: Only fetch this number of observations

          r: Fetch observations from up to 10 locations

          spp_locale: Use this language for species common names

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not region_code:
            raise ValueError(f"Expected a non-empty value for `region_code` but received {region_code!r}")
        return self._get(
            f"/data/obs/{region_code}/recent",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform(
                    {
                        "back": back,
                        "cat": cat,
                        "hotspot": hotspot,
                        "include_provisional": include_provisional,
                        "max_results": max_results,
                        "r": r,
                        "spp_locale": spp_locale,
                    },
                    recent_list_params.RecentListParams,
                ),
            ),
            cast_to=RecentListResponse,
        )


class AsyncRecentResource(AsyncAPIResource):
    @cached_property
    def notable(self) -> AsyncNotableResource:
        return AsyncNotableResource(self._client)

    @cached_property
    def species(self) -> AsyncSpeciesResource:
        return AsyncSpeciesResource(self._client)

    @cached_property
    def historic(self) -> AsyncHistoricResource:
        return AsyncHistoricResource(self._client)

    @cached_property
    def with_raw_response(self) -> AsyncRecentResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/phoebe-bird/phoebe-python#accessing-raw-response-data-eg-headers
        """
        return AsyncRecentResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncRecentResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/phoebe-bird/phoebe-python#with_streaming_response
        """
        return AsyncRecentResourceWithStreamingResponse(self)

    async def list(
        self,
        region_code: str,
        *,
        back: int | NotGiven = NOT_GIVEN,
        cat: Literal["species", "slash", "issf", "spuh", "hybrid", "domestic", "form", "intergrade"]
        | NotGiven = NOT_GIVEN,
        hotspot: bool | NotGiven = NOT_GIVEN,
        include_provisional: bool | NotGiven = NOT_GIVEN,
        max_results: int | NotGiven = NOT_GIVEN,
        r: List[str] | NotGiven = NOT_GIVEN,
        spp_locale: str | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> RecentListResponse:
        """
        Get the list of recent observations (up to 30 days ago) of birds seen in a
        country, state, county, or location. Results include only the most recent
        observation for each species in the region specified.

        Args:
          back: The number of days back to fetch observations.

          cat: Only fetch observations from these taxonomic categories

          hotspot: Only fetch observations from hotspots

          include_provisional: Include observations which have not yet been reviewed

          max_results: Only fetch this number of observations

          r: Fetch observations from up to 10 locations

          spp_locale: Use this language for species common names

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not region_code:
            raise ValueError(f"Expected a non-empty value for `region_code` but received {region_code!r}")
        return await self._get(
            f"/data/obs/{region_code}/recent",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=await async_maybe_transform(
                    {
                        "back": back,
                        "cat": cat,
                        "hotspot": hotspot,
                        "include_provisional": include_provisional,
                        "max_results": max_results,
                        "r": r,
                        "spp_locale": spp_locale,
                    },
                    recent_list_params.RecentListParams,
                ),
            ),
            cast_to=RecentListResponse,
        )


class RecentResourceWithRawResponse:
    def __init__(self, recent: RecentResource) -> None:
        self._recent = recent

        self.list = to_raw_response_wrapper(
            recent.list,
        )

    @cached_property
    def notable(self) -> NotableResourceWithRawResponse:
        return NotableResourceWithRawResponse(self._recent.notable)

    @cached_property
    def species(self) -> SpeciesResourceWithRawResponse:
        return SpeciesResourceWithRawResponse(self._recent.species)

    @cached_property
    def historic(self) -> HistoricResourceWithRawResponse:
        return HistoricResourceWithRawResponse(self._recent.historic)


class AsyncRecentResourceWithRawResponse:
    def __init__(self, recent: AsyncRecentResource) -> None:
        self._recent = recent

        self.list = async_to_raw_response_wrapper(
            recent.list,
        )

    @cached_property
    def notable(self) -> AsyncNotableResourceWithRawResponse:
        return AsyncNotableResourceWithRawResponse(self._recent.notable)

    @cached_property
    def species(self) -> AsyncSpeciesResourceWithRawResponse:
        return AsyncSpeciesResourceWithRawResponse(self._recent.species)

    @cached_property
    def historic(self) -> AsyncHistoricResourceWithRawResponse:
        return AsyncHistoricResourceWithRawResponse(self._recent.historic)


class RecentResourceWithStreamingResponse:
    def __init__(self, recent: RecentResource) -> None:
        self._recent = recent

        self.list = to_streamed_response_wrapper(
            recent.list,
        )

    @cached_property
    def notable(self) -> NotableResourceWithStreamingResponse:
        return NotableResourceWithStreamingResponse(self._recent.notable)

    @cached_property
    def species(self) -> SpeciesResourceWithStreamingResponse:
        return SpeciesResourceWithStreamingResponse(self._recent.species)

    @cached_property
    def historic(self) -> HistoricResourceWithStreamingResponse:
        return HistoricResourceWithStreamingResponse(self._recent.historic)


class AsyncRecentResourceWithStreamingResponse:
    def __init__(self, recent: AsyncRecentResource) -> None:
        self._recent = recent

        self.list = async_to_streamed_response_wrapper(
            recent.list,
        )

    @cached_property
    def notable(self) -> AsyncNotableResourceWithStreamingResponse:
        return AsyncNotableResourceWithStreamingResponse(self._recent.notable)

    @cached_property
    def species(self) -> AsyncSpeciesResourceWithStreamingResponse:
        return AsyncSpeciesResourceWithStreamingResponse(self._recent.species)

    @cached_property
    def historic(self) -> AsyncHistoricResourceWithStreamingResponse:
        return AsyncHistoricResourceWithStreamingResponse(self._recent.historic)



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from .ebird import (
    EbirdResource,
    AsyncEbirdResource,
    EbirdResourceWithRawResponse,
    AsyncEbirdResourceWithRawResponse,
    EbirdResourceWithStreamingResponse,
    AsyncEbirdResourceWithStreamingResponse,
)
from .forms import (
    FormsResource,
    AsyncFormsResource,
    FormsResourceWithRawResponse,
    AsyncFormsResourceWithRawResponse,
    FormsResourceWithStreamingResponse,
    AsyncFormsResourceWithStreamingResponse,
)
from .locales import (
    LocalesResource,
    AsyncLocalesResource,
    LocalesResourceWithRawResponse,
    AsyncLocalesResourceWithRawResponse,
    LocalesResourceWithStreamingResponse,
    AsyncLocalesResourceWithStreamingResponse,
)
from .versions import (
    VersionsResource,
    AsyncVersionsResource,
    VersionsResourceWithRawResponse,
    AsyncVersionsResourceWithRawResponse,
    VersionsResourceWithStreamingResponse,
    AsyncVersionsResourceWithStreamingResponse,
)
from ...._compat import cached_property
from ...._resource import SyncAPIResource, AsyncAPIResource
from .species_groups import (
    SpeciesGroupsResource,
    AsyncSpeciesGroupsResource,
    SpeciesGroupsResourceWithRawResponse,
    AsyncSpeciesGroupsResourceWithRawResponse,
    SpeciesGroupsResourceWithStreamingResponse,
    AsyncSpeciesGroupsResourceWithStreamingResponse,
)

__all__ = ["TaxonomyResource", "AsyncTaxonomyResource"]


class TaxonomyResource(SyncAPIResource):
    @cached_property
    def ebird(self) -> EbirdResource:
        return EbirdResource(self._client)

    @cached_property
    def forms(self) -> FormsResource:
        return FormsResource(self._client)

    @cached_property
    def locales(self) -> LocalesResource:
        return LocalesResource(self._client)

    @cached_property
    def versions(self) -> VersionsResource:
        return VersionsResource(self._client)

    @cached_property
    def species_groups(self) -> SpeciesGroupsResource:
        return SpeciesGroupsResource(self._client)

    @cached_property
    def with_raw_response(self) -> TaxonomyResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/phoebe-bird/phoebe-python#accessing-raw-response-data-eg-headers
        """
        return TaxonomyResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> TaxonomyResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/phoebe-bird/phoebe-python#with_streaming_response
        """
        return TaxonomyResourceWithStreamingResponse(self)


class AsyncTaxonomyResource(AsyncAPIResource):
    @cached_property
    def ebird(self) -> AsyncEbirdResource:
        return AsyncEbirdResource(self._client)

    @cached_property
    def forms(self) -> AsyncFormsResource:
        return AsyncFormsResource(self._client)

    @cached_property
    def locales(self) -> AsyncLocalesResource:
        return AsyncLocalesResource(self._client)

    @cached_property
    def versions(self) -> AsyncVersionsResource:
        return AsyncVersionsResource(self._client)

    @cached_property
    def species_groups(self) -> AsyncSpeciesGroupsResource:
        return AsyncSpeciesGroupsResource(self._client)

    @cached_property
    def with_raw_response(self) -> AsyncTaxonomyResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/phoebe-bird/phoebe-python#accessing-raw-response-data-eg-headers
        """
        return AsyncTaxonomyResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncTaxonomyResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/phoebe-bird/phoebe-python#with_streaming_response
        """
        return AsyncTaxonomyResourceWithStreamingResponse(self)


class TaxonomyResourceWithRawResponse:
    def __init__(self, taxonomy: TaxonomyResource) -> None:
        self._taxonomy = taxonomy

    @cached_property
    def ebird(self) -> EbirdResourceWithRawResponse:
        return EbirdResourceWithRawResponse(self._taxonomy.ebird)

    @cached_property
    def forms(self) -> FormsResourceWithRawResponse:
        return FormsResourceWithRawResponse(self._taxonomy.forms)

    @cached_property
    def locales(self) -> LocalesResourceWithRawResponse:
        return LocalesResourceWithRawResponse(self._taxonomy.locales)

    @cached_property
    def versions(self) -> VersionsResourceWithRawResponse:
        return VersionsResourceWithRawResponse(self._taxonomy.versions)

    @cached_property
    def species_groups(self) -> SpeciesGroupsResourceWithRawResponse:
        return SpeciesGroupsResourceWithRawResponse(self._taxonomy.species_groups)


class AsyncTaxonomyResourceWithRawResponse:
    def __init__(self, taxonomy: AsyncTaxonomyResource) -> None:
        self._taxonomy = taxonomy

    @cached_property
    def ebird(self) -> AsyncEbirdResourceWithRawResponse:
        return AsyncEbirdResourceWithRawResponse(self._taxonomy.ebird)

    @cached_property
    def forms(self) -> AsyncFormsResourceWithRawResponse:
        return AsyncFormsResourceWithRawResponse(self._taxonomy.forms)

    @cached_property
    def locales(self) -> AsyncLocalesResourceWithRawResponse:
        return AsyncLocalesResourceWithRawResponse(self._taxonomy.locales)

    @cached_property
    def versions(self) -> AsyncVersionsResourceWithRawResponse:
        return AsyncVersionsResourceWithRawResponse(self._taxonomy.versions)

    @cached_property
    def species_groups(self) -> AsyncSpeciesGroupsResourceWithRawResponse:
        return AsyncSpeciesGroupsResourceWithRawResponse(self._taxonomy.species_groups)


class TaxonomyResourceWithStreamingResponse:
    def __init__(self, taxonomy: TaxonomyResource) -> None:
        self._taxonomy = taxonomy

    @cached_property
    def ebird(self) -> EbirdResourceWithStreamingResponse:
        return EbirdResourceWithStreamingResponse(self._taxonomy.ebird)

    @cached_property
    def forms(self) -> FormsResourceWithStreamingResponse:
        return FormsResourceWithStreamingResponse(self._taxonomy.forms)

    @cached_property
    def locales(self) -> LocalesResourceWithStreamingResponse:
        return LocalesResourceWithStreamingResponse(self._taxonomy.locales)

    @cached_property
    def versions(self) -> VersionsResourceWithStreamingResponse:
        return VersionsResourceWithStreamingResponse(self._taxonomy.versions)

    @cached_property
    def species_groups(self) -> SpeciesGroupsResourceWithStreamingResponse:
        return SpeciesGroupsResourceWithStreamingResponse(self._taxonomy.species_groups)


class AsyncTaxonomyResourceWithStreamingResponse:
    def __init__(self, taxonomy: AsyncTaxonomyResource) -> None:
        self._taxonomy = taxonomy

    @cached_property
    def ebird(self) -> AsyncEbirdResourceWithStreamingResponse:
        return AsyncEbirdResourceWithStreamingResponse(self._taxonomy.ebird)

    @cached_property
    def forms(self) -> AsyncFormsResourceWithStreamingResponse:
        return AsyncFormsResourceWithStreamingResponse(self._taxonomy.forms)

    @cached_property
    def locales(self) -> AsyncLocalesResourceWithStreamingResponse:
        return AsyncLocalesResourceWithStreamingResponse(self._taxonomy.locales)

    @cached_property
    def versions(self) -> AsyncVersionsResourceWithStreamingResponse:
        return AsyncVersionsResourceWithStreamingResponse(self._taxonomy.versions)

    @cached_property
    def species_groups(self) -> AsyncSpeciesGroupsResourceWithStreamingResponse:
        return AsyncSpeciesGroupsResourceWithStreamingResponse(self._taxonomy.species_groups)



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import httpx

from ...._types import NOT_GIVEN, Body, Query, Headers, NotGiven
from ...._compat import cached_property
from ...._resource import SyncAPIResource, AsyncAPIResource
from ...._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from ...._base_client import make_request_options
from ....types.ref.taxonomy.version_list_response import VersionListResponse

__all__ = ["VersionsResource", "AsyncVersionsResource"]


class VersionsResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> VersionsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/phoebe-bird/phoebe-python#accessing-raw-response-data-eg-headers
        """
        return VersionsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> VersionsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/phoebe-bird/phoebe-python#with_streaming_response
        """
        return VersionsResourceWithStreamingResponse(self)

    def list(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> VersionListResponse:
        """
        Returns a list of all versions of the taxonomy, with a flag indicating which is
        the latest.
        """
        return self._get(
            "/ref/taxonomy/versions",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=VersionListResponse,
        )


class AsyncVersionsResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncVersionsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/phoebe-bird/phoebe-python#accessing-raw-response-data-eg-headers
        """
        return AsyncVersionsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncVersionsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/phoebe-bird/phoebe-python#with_streaming_response
        """
        return AsyncVersionsResourceWithStreamingResponse(self)

    async def list(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> VersionListResponse:
        """
        Returns a list of all versions of the taxonomy, with a flag indicating which is
        the latest.
        """
        return await self._get(
            "/ref/taxonomy/versions",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=VersionListResponse,
        )


class VersionsResourceWithRawResponse:
    def __init__(self, versions: VersionsResource) -> None:
        self._versions = versions

        self.list = to_raw_response_wrapper(
            versions.list,
        )


class AsyncVersionsResourceWithRawResponse:
    def __init__(self, versions: AsyncVersionsResource) -> None:
        self._versions = versions

        self.list = async_to_raw_response_wrapper(
            versions.list,
        )


class VersionsResourceWithStreamingResponse:
    def __init__(self, versions: VersionsResource) -> None:
        self._versions = versions

        self.list = to_streamed_response_wrapper(
            versions.list,
        )


class AsyncVersionsResourceWithStreamingResponse:
    def __init__(self, versions: AsyncVersionsResource) -> None:
        self._versions = versions

        self.list = async_to_streamed_response_wrapper(
            versions.list,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional

from pydantic import Field as FieldInfo

from ..._models import BaseModel

__all__ = ["StatRetrieveResponse"]


class StatRetrieveResponse(BaseModel):
    num_checklists: Optional[int] = FieldInfo(alias="numChecklists", default=None)

    num_contributors: Optional[int] = FieldInfo(alias="numContributors", default=None)

    num_species: Optional[int] = FieldInfo(alias="numSpecies", default=None)



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import List
from typing_extensions import Literal, Annotated, TypedDict

from ....._utils import PropertyInfo

__all__ = ["NotableListParams"]


class NotableListParams(TypedDict, total=False):
    back: int
    """The number of days back to fetch observations."""

    detail: Literal["simple", "full"]
    """Include a subset (simple), or all (full), of the fields available."""

    hotspot: bool
    """Only fetch observations from hotspots"""

    max_results: Annotated[int, PropertyInfo(alias="maxResults")]
    """Only fetch this number of observations"""

    r: List[str]
    """Fetch observations from up to 10 locations"""

    spp_locale: Annotated[str, PropertyInfo(alias="sppLocale")]
    """Use this language for species common names"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from .ref import (
    RefResource,
    AsyncRefResource,
    RefResourceWithRawResponse,
    AsyncRefResourceWithRawResponse,
    RefResourceWithStreamingResponse,
    AsyncRefResourceWithStreamingResponse,
)
from .data import (
    DataResource,
    AsyncDataResource,
    DataResourceWithRawResponse,
    AsyncDataResourceWithRawResponse,
    DataResourceWithStreamingResponse,
    AsyncDataResourceWithStreamingResponse,
)
from .product import (
    ProductResource,
    AsyncProductResource,
    ProductResourceWithRawResponse,
    AsyncProductResourceWithRawResponse,
    ProductResourceWithStreamingResponse,
    AsyncProductResourceWithStreamingResponse,
)

__all__ = [
    "DataResource",
    "AsyncDataResource",
    "DataResourceWithRawResponse",
    "AsyncDataResourceWithRawResponse",
    "DataResourceWithStreamingResponse",
    "AsyncDataResourceWithStreamingResponse",
    "ProductResource",
    "AsyncProductResource",
    "ProductResourceWithRawResponse",
    "AsyncProductResourceWithRawResponse",
    "ProductResourceWithStreamingResponse",
    "AsyncProductResourceWithStreamingResponse",
    "RefResource",
    "AsyncRefResource",
    "RefResourceWithRawResponse",
    "AsyncRefResourceWithRawResponse",
    "RefResourceWithStreamingResponse",
    "AsyncRefResourceWithStreamingResponse",
]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional
from typing_extensions import TypeAlias

from pydantic import Field as FieldInfo

from ...._models import BaseModel

__all__ = ["SpeciesGroupListResponse", "SpeciesGroupListResponseItem"]


class SpeciesGroupListResponseItem(BaseModel):
    group_name: Optional[str] = FieldInfo(alias="groupName", default=None)

    group_order: Optional[int] = FieldInfo(alias="groupOrder", default=None)

    taxon_order_bounds: Optional[List[List[float]]] = FieldInfo(alias="taxonOrderBounds", default=None)


SpeciesGroupListResponse: TypeAlias = List[SpeciesGroupListResponseItem]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from .lists import (
    ListsResource,
    AsyncListsResource,
    ListsResourceWithRawResponse,
    AsyncListsResourceWithRawResponse,
    ListsResourceWithStreamingResponse,
    AsyncListsResourceWithStreamingResponse,
)
from .stats import (
    StatsResource,
    AsyncStatsResource,
    StatsResourceWithRawResponse,
    AsyncStatsResourceWithRawResponse,
    StatsResourceWithStreamingResponse,
    AsyncStatsResourceWithStreamingResponse,
)
from .top100 import (
    Top100Resource,
    AsyncTop100Resource,
    Top100ResourceWithRawResponse,
    AsyncTop100ResourceWithRawResponse,
    Top100ResourceWithStreamingResponse,
    AsyncTop100ResourceWithStreamingResponse,
)
from .product import (
    ProductResource,
    AsyncProductResource,
    ProductResourceWithRawResponse,
    AsyncProductResourceWithRawResponse,
    ProductResourceWithStreamingResponse,
    AsyncProductResourceWithStreamingResponse,
)
from .checklist import (
    ChecklistResource,
    AsyncChecklistResource,
    ChecklistResourceWithRawResponse,
    AsyncChecklistResourceWithRawResponse,
    ChecklistResourceWithStreamingResponse,
    AsyncChecklistResourceWithStreamingResponse,
)
from .species_list import (
    SpeciesListResource,
    AsyncSpeciesListResource,
    SpeciesListResourceWithRawResponse,
    AsyncSpeciesListResourceWithRawResponse,
    SpeciesListResourceWithStreamingResponse,
    AsyncSpeciesListResourceWithStreamingResponse,
)

__all__ = [
    "ListsResource",
    "AsyncListsResource",
    "ListsResourceWithRawResponse",
    "AsyncListsResourceWithRawResponse",
    "ListsResourceWithStreamingResponse",
    "AsyncListsResourceWithStreamingResponse",
    "Top100Resource",
    "AsyncTop100Resource",
    "Top100ResourceWithRawResponse",
    "AsyncTop100ResourceWithRawResponse",
    "Top100ResourceWithStreamingResponse",
    "AsyncTop100ResourceWithStreamingResponse",
    "StatsResource",
    "AsyncStatsResource",
    "StatsResourceWithRawResponse",
    "AsyncStatsResourceWithRawResponse",
    "StatsResourceWithStreamingResponse",
    "AsyncStatsResourceWithStreamingResponse",
    "SpeciesListResource",
    "AsyncSpeciesListResource",
    "SpeciesListResourceWithRawResponse",
    "AsyncSpeciesListResourceWithRawResponse",
    "SpeciesListResourceWithStreamingResponse",
    "AsyncSpeciesListResourceWithStreamingResponse",
    "ChecklistResource",
    "AsyncChecklistResource",
    "ChecklistResourceWithRawResponse",
    "AsyncChecklistResourceWithRawResponse",
    "ChecklistResourceWithStreamingResponse",
    "AsyncChecklistResourceWithStreamingResponse",
    "ProductResource",
    "AsyncProductResource",
    "ProductResourceWithRawResponse",
    "AsyncProductResourceWithRawResponse",
    "ProductResourceWithStreamingResponse",
    "AsyncProductResourceWithStreamingResponse",
]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional
from typing_extensions import TypeAlias

from ...._models import BaseModel

__all__ = ["AdjacentListResponse", "AdjacentListResponseItem"]


class AdjacentListResponseItem(BaseModel):
    code: Optional[str] = None

    name: Optional[str] = None


AdjacentListResponse: TypeAlias = List[AdjacentListResponseItem]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Literal

import httpx

from ...._types import NOT_GIVEN, Body, Query, Headers, NotGiven
from ...._utils import maybe_transform, async_maybe_transform
from ...._compat import cached_property
from ...._resource import SyncAPIResource, AsyncAPIResource
from ...._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from ...._base_client import make_request_options
from ....types.ref.hotspot import geo_retrieve_params
from ....types.ref.hotspot.geo_retrieve_response import GeoRetrieveResponse

__all__ = ["GeoResource", "AsyncGeoResource"]


class GeoResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> GeoResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/phoebe-bird/phoebe-python#accessing-raw-response-data-eg-headers
        """
        return GeoResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> GeoResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/phoebe-bird/phoebe-python#with_streaming_response
        """
        return GeoResourceWithStreamingResponse(self)

    def retrieve(
        self,
        *,
        lat: float,
        lng: float,
        back: int | NotGiven = NOT_GIVEN,
        dist: int | NotGiven = NOT_GIVEN,
        fmt: Literal["csv", "json"] | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> GeoRetrieveResponse:
        """
        Get the list of hotspots, within a radius of up to 50 kilometers, from a given
        set of coordinates.

        Args:
          back: The number of days back to fetch hotspots.

          dist: The search radius from the given position, in kilometers.

          fmt: Fetch the records in CSV or JSON format.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._get(
            "/ref/hotspot/geo",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform(
                    {
                        "lat": lat,
                        "lng": lng,
                        "back": back,
                        "dist": dist,
                        "fmt": fmt,
                    },
                    geo_retrieve_params.GeoRetrieveParams,
                ),
            ),
            cast_to=GeoRetrieveResponse,
        )


class AsyncGeoResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncGeoResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/phoebe-bird/phoebe-python#accessing-raw-response-data-eg-headers
        """
        return AsyncGeoResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncGeoResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/phoebe-bird/phoebe-python#with_streaming_response
        """
        return AsyncGeoResourceWithStreamingResponse(self)

    async def retrieve(
        self,
        *,
        lat: float,
        lng: float,
        back: int | NotGiven = NOT_GIVEN,
        dist: int | NotGiven = NOT_GIVEN,
        fmt: Literal["csv", "json"] | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> GeoRetrieveResponse:
        """
        Get the list of hotspots, within a radius of up to 50 kilometers, from a given
        set of coordinates.

        Args:
          back: The number of days back to fetch hotspots.

          dist: The search radius from the given position, in kilometers.

          fmt: Fetch the records in CSV or JSON format.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return await self._get(
            "/ref/hotspot/geo",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=await async_maybe_transform(
                    {
                        "lat": lat,
                        "lng": lng,
                        "back": back,
                        "dist": dist,
                        "fmt": fmt,
                    },
                    geo_retrieve_params.GeoRetrieveParams,
                ),
            ),
            cast_to=GeoRetrieveResponse,
        )


class GeoResourceWithRawResponse:
    def __init__(self, geo: GeoResource) -> None:
        self._geo = geo

        self.retrieve = to_raw_response_wrapper(
            geo.retrieve,
        )


class AsyncGeoResourceWithRawResponse:
    def __init__(self, geo: AsyncGeoResource) -> None:
        self._geo = geo

        self.retrieve = async_to_raw_response_wrapper(
            geo.retrieve,
        )


class GeoResourceWithStreamingResponse:
    def __init__(self, geo: GeoResource) -> None:
        self._geo = geo

        self.retrieve = to_streamed_response_wrapper(
            geo.retrieve,
        )


class AsyncGeoResourceWithStreamingResponse:
    def __init__(self, geo: AsyncGeoResource) -> None:
        self._geo = geo

        self.retrieve = async_to_streamed_response_wrapper(
            geo.retrieve,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Literal

import httpx

from .geo import (
    GeoResource,
    AsyncGeoResource,
    GeoResourceWithRawResponse,
    AsyncGeoResourceWithRawResponse,
    GeoResourceWithStreamingResponse,
    AsyncGeoResourceWithStreamingResponse,
)
from .info import (
    InfoResource,
    AsyncInfoResource,
    InfoResourceWithRawResponse,
    AsyncInfoResourceWithRawResponse,
    InfoResourceWithStreamingResponse,
    AsyncInfoResourceWithStreamingResponse,
)
from ...._types import NOT_GIVEN, Body, Query, Headers, NotGiven
from ...._utils import maybe_transform, async_maybe_transform
from ...._compat import cached_property
from ...._resource import SyncAPIResource, AsyncAPIResource
from ...._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from ....types.ref import hotspot_list_params
from ...._base_client import make_request_options
from ....types.ref.hotspot_list_response import HotspotListResponse

__all__ = ["HotspotResource", "AsyncHotspotResource"]


class HotspotResource(SyncAPIResource):
    @cached_property
    def geo(self) -> GeoResource:
        return GeoResource(self._client)

    @cached_property
    def info(self) -> InfoResource:
        return InfoResource(self._client)

    @cached_property
    def with_raw_response(self) -> HotspotResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/phoebe-bird/phoebe-python#accessing-raw-response-data-eg-headers
        """
        return HotspotResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> HotspotResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/phoebe-bird/phoebe-python#with_streaming_response
        """
        return HotspotResourceWithStreamingResponse(self)

    def list(
        self,
        region_code: str,
        *,
        back: int | NotGiven = NOT_GIVEN,
        fmt: Literal["csv", "json"] | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> HotspotListResponse:
        """
        Hotspots in a region

        Args:
          back: The number of days back to fetch hotspots.

          fmt: Fetch the records in CSV or JSON format.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not region_code:
            raise ValueError(f"Expected a non-empty value for `region_code` but received {region_code!r}")
        return self._get(
            f"/ref/hotspot/{region_code}",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform(
                    {
                        "back": back,
                        "fmt": fmt,
                    },
                    hotspot_list_params.HotspotListParams,
                ),
            ),
            cast_to=HotspotListResponse,
        )


class AsyncHotspotResource(AsyncAPIResource):
    @cached_property
    def geo(self) -> AsyncGeoResource:
        return AsyncGeoResource(self._client)

    @cached_property
    def info(self) -> AsyncInfoResource:
        return AsyncInfoResource(self._client)

    @cached_property
    def with_raw_response(self) -> AsyncHotspotResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/phoebe-bird/phoebe-python#accessing-raw-response-data-eg-headers
        """
        return AsyncHotspotResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncHotspotResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/phoebe-bird/phoebe-python#with_streaming_response
        """
        return AsyncHotspotResourceWithStreamingResponse(self)

    async def list(
        self,
        region_code: str,
        *,
        back: int | NotGiven = NOT_GIVEN,
        fmt: Literal["csv", "json"] | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> HotspotListResponse:
        """
        Hotspots in a region

        Args:
          back: The number of days back to fetch hotspots.

          fmt: Fetch the records in CSV or JSON format.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not region_code:
            raise ValueError(f"Expected a non-empty value for `region_code` but received {region_code!r}")
        return await self._get(
            f"/ref/hotspot/{region_code}",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=await async_maybe_transform(
                    {
                        "back": back,
                        "fmt": fmt,
                    },
                    hotspot_list_params.HotspotListParams,
                ),
            ),
            cast_to=HotspotListResponse,
        )


class HotspotResourceWithRawResponse:
    def __init__(self, hotspot: HotspotResource) -> None:
        self._hotspot = hotspot

        self.list = to_raw_response_wrapper(
            hotspot.list,
        )

    @cached_property
    def geo(self) -> GeoResourceWithRawResponse:
        return GeoResourceWithRawResponse(self._hotspot.geo)

    @cached_property
    def info(self) -> InfoResourceWithRawResponse:
        return InfoResourceWithRawResponse(self._hotspot.info)


class AsyncHotspotResourceWithRawResponse:
    def __init__(self, hotspot: AsyncHotspotResource) -> None:
        self._hotspot = hotspot

        self.list = async_to_raw_response_wrapper(
            hotspot.list,
        )

    @cached_property
    def geo(self) -> AsyncGeoResourceWithRawResponse:
        return AsyncGeoResourceWithRawResponse(self._hotspot.geo)

    @cached_property
    def info(self) -> AsyncInfoResourceWithRawResponse:
        return AsyncInfoResourceWithRawResponse(self._hotspot.info)


class HotspotResourceWithStreamingResponse:
    def __init__(self, hotspot: HotspotResource) -> None:
        self._hotspot = hotspot

        self.list = to_streamed_response_wrapper(
            hotspot.list,
        )

    @cached_property
    def geo(self) -> GeoResourceWithStreamingResponse:
        return GeoResourceWithStreamingResponse(self._hotspot.geo)

    @cached_property
    def info(self) -> InfoResourceWithStreamingResponse:
        return InfoResourceWithStreamingResponse(self._hotspot.info)


class AsyncHotspotResourceWithStreamingResponse:
    def __init__(self, hotspot: AsyncHotspotResource) -> None:
        self._hotspot = hotspot

        self.list = async_to_streamed_response_wrapper(
            hotspot.list,
        )

    @cached_property
    def geo(self) -> AsyncGeoResourceWithStreamingResponse:
        return AsyncGeoResourceWithStreamingResponse(self._hotspot.geo)

    @cached_property
    def info(self) -> AsyncInfoResourceWithStreamingResponse:
        return AsyncInfoResourceWithStreamingResponse(self._hotspot.info)



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import List
from typing_extensions import Required, Annotated, TypedDict

from ....._utils import PropertyInfo

__all__ = ["SpecieRetrieveParams"]


class SpecieRetrieveParams(TypedDict, total=False):
    region_code: Required[Annotated[str, PropertyInfo(alias="regionCode")]]

    back: int
    """The number of days back to fetch observations."""

    hotspot: bool
    """Only fetch observations from hotspots"""

    include_provisional: Annotated[bool, PropertyInfo(alias="includeProvisional")]
    """Include observations which have not yet been reviewed."""

    max_results: Annotated[int, PropertyInfo(alias="maxResults")]
    """Only fetch this number of observations"""

    r: List[str]
    """Fetch observations from up to 10 locations"""

    spp_locale: Annotated[str, PropertyInfo(alias="sppLocale")]
    """Use this language for species common names"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from .geo import (
    GeoResource,
    AsyncGeoResource,
    GeoResourceWithRawResponse,
    AsyncGeoResourceWithRawResponse,
    GeoResourceWithStreamingResponse,
    AsyncGeoResourceWithStreamingResponse,
)
from .recent import (
    RecentResource,
    AsyncRecentResource,
    RecentResourceWithRawResponse,
    AsyncRecentResourceWithRawResponse,
    RecentResourceWithStreamingResponse,
    AsyncRecentResourceWithStreamingResponse,
)

__all__ = [
    "RecentResource",
    "AsyncRecentResource",
    "RecentResourceWithRawResponse",
    "AsyncRecentResourceWithRawResponse",
    "RecentResourceWithStreamingResponse",
    "AsyncRecentResourceWithStreamingResponse",
    "GeoResource",
    "AsyncGeoResource",
    "GeoResourceWithRawResponse",
    "AsyncGeoResourceWithRawResponse",
    "GeoResourceWithStreamingResponse",
    "AsyncGeoResourceWithStreamingResponse",
]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from .list_list_params import ListListParams as ListListParams
from .list_list_response import ListListResponse as ListListResponse
from .info_retrieve_params import InfoRetrieveParams as InfoRetrieveParams
from .adjacent_list_response import AdjacentListResponse as AdjacentListResponse
from .info_retrieve_response import InfoRetrieveResponse as InfoRetrieveResponse



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Literal, Annotated, TypedDict

from ...._utils import PropertyInfo

__all__ = ["InfoRetrieveParams"]


class InfoRetrieveParams(TypedDict, total=False):
    delim: str
    """The characters used to separate elements in the name."""

    region_name_format: Annotated[
        Literal["detailed", "detailednoqual", "full", "namequal", "nameonly", "revdetailed"],
        PropertyInfo(alias="regionNameFormat"),
    ]
    """Control how the name is displayed."""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional
from typing_extensions import TypeAlias

from pydantic import Field as FieldInfo

from ...._models import BaseModel

__all__ = ["VersionListResponse", "VersionListResponseItem"]


class VersionListResponseItem(BaseModel):
    authority_ver: Optional[float] = FieldInfo(alias="authorityVer", default=None)

    latest: Optional[bool] = None


VersionListResponse: TypeAlias = List[VersionListResponseItem]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Literal, Required, Annotated, TypedDict

from ...._utils import PropertyInfo

__all__ = ["HistoricalRetrieveParams"]


class HistoricalRetrieveParams(TypedDict, total=False):
    region_code: Required[Annotated[str, PropertyInfo(alias="regionCode")]]

    y: Required[int]

    m: Required[int]

    max_results: Annotated[int, PropertyInfo(alias="maxResults")]
    """Only fetch this number of checklists."""

    sort_key: Annotated[Literal["obs_dt", "creation_dt"], PropertyInfo(alias="sortKey")]
    """Order the results by the date of the checklist or by the date it was submitted."""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from .geo import (
    GeoResource,
    AsyncGeoResource,
    GeoResourceWithRawResponse,
    AsyncGeoResourceWithRawResponse,
    GeoResourceWithStreamingResponse,
    AsyncGeoResourceWithStreamingResponse,
)
from .info import (
    InfoResource,
    AsyncInfoResource,
    InfoResourceWithRawResponse,
    AsyncInfoResourceWithRawResponse,
    InfoResourceWithStreamingResponse,
    AsyncInfoResourceWithStreamingResponse,
)
from .hotspot import (
    HotspotResource,
    AsyncHotspotResource,
    HotspotResourceWithRawResponse,
    AsyncHotspotResourceWithRawResponse,
    HotspotResourceWithStreamingResponse,
    AsyncHotspotResourceWithStreamingResponse,
)

__all__ = [
    "GeoResource",
    "AsyncGeoResource",
    "GeoResourceWithRawResponse",
    "AsyncGeoResourceWithRawResponse",
    "GeoResourceWithStreamingResponse",
    "AsyncGeoResourceWithStreamingResponse",
    "InfoResource",
    "AsyncInfoResource",
    "InfoResourceWithRawResponse",
    "AsyncInfoResourceWithRawResponse",
    "InfoResourceWithStreamingResponse",
    "AsyncInfoResourceWithStreamingResponse",
    "HotspotResource",
    "AsyncHotspotResource",
    "HotspotResourceWithRawResponse",
    "AsyncHotspotResourceWithRawResponse",
    "HotspotResourceWithStreamingResponse",
    "AsyncHotspotResourceWithStreamingResponse",
]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Literal

import httpx

from ......_types import NOT_GIVEN, Body, Query, Headers, NotGiven
from ......_utils import maybe_transform, async_maybe_transform
from ......_compat import cached_property
from ......_resource import SyncAPIResource, AsyncAPIResource
from ......_response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from ......_base_client import make_request_options
from ......types.data.observations.geo.recent import notable_list_params
from ......types.data.observations.geo.recent.notable_list_response import NotableListResponse

__all__ = ["NotableResource", "AsyncNotableResource"]


class NotableResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> NotableResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/phoebe-bird/phoebe-python#accessing-raw-response-data-eg-headers
        """
        return NotableResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> NotableResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/phoebe-bird/phoebe-python#with_streaming_response
        """
        return NotableResourceWithStreamingResponse(self)

    def list(
        self,
        *,
        lat: float,
        lng: float,
        back: int | NotGiven = NOT_GIVEN,
        detail: Literal["simple", "full"] | NotGiven = NOT_GIVEN,
        dist: int | NotGiven = NOT_GIVEN,
        hotspot: bool | NotGiven = NOT_GIVEN,
        max_results: int | NotGiven = NOT_GIVEN,
        spp_locale: str | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> NotableListResponse:
        """
        Get the list of notable observations (up to 30 days ago) of birds seen at
        locations within a radius of up to 50 kilometers, from a given set of
        coordinates. Notable observations can be for locally or nationally rare species
        or are otherwise unusual, for example over-wintering birds in a species which is
        normally only a summer visitor.

        Args:
          back: The number of days back to fetch observations.

          detail: Include a subset (simple), or all (full), of the fields available.

          dist: The search radius from the given position, in kilometers.

          hotspot: Only fetch observations from hotspots

          max_results: Only fetch this number of observations

          spp_locale: Use this language for species common names

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._get(
            "/data/obs/geo/recent/notable",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform(
                    {
                        "lat": lat,
                        "lng": lng,
                        "back": back,
                        "detail": detail,
                        "dist": dist,
                        "hotspot": hotspot,
                        "max_results": max_results,
                        "spp_locale": spp_locale,
                    },
                    notable_list_params.NotableListParams,
                ),
            ),
            cast_to=NotableListResponse,
        )


class AsyncNotableResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncNotableResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/phoebe-bird/phoebe-python#accessing-raw-response-data-eg-headers
        """
        return AsyncNotableResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncNotableResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/phoebe-bird/phoebe-python#with_streaming_response
        """
        return AsyncNotableResourceWithStreamingResponse(self)

    async def list(
        self,
        *,
        lat: float,
        lng: float,
        back: int | NotGiven = NOT_GIVEN,
        detail: Literal["simple", "full"] | NotGiven = NOT_GIVEN,
        dist: int | NotGiven = NOT_GIVEN,
        hotspot: bool | NotGiven = NOT_GIVEN,
        max_results: int | NotGiven = NOT_GIVEN,
        spp_locale: str | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> NotableListResponse:
        """
        Get the list of notable observations (up to 30 days ago) of birds seen at
        locations within a radius of up to 50 kilometers, from a given set of
        coordinates. Notable observations can be for locally or nationally rare species
        or are otherwise unusual, for example over-wintering birds in a species which is
        normally only a summer visitor.

        Args:
          back: The number of days back to fetch observations.

          detail: Include a subset (simple), or all (full), of the fields available.

          dist: The search radius from the given position, in kilometers.

          hotspot: Only fetch observations from hotspots

          max_results: Only fetch this number of observations

          spp_locale: Use this language for species common names

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return await self._get(
            "/data/obs/geo/recent/notable",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=await async_maybe_transform(
                    {
                        "lat": lat,
                        "lng": lng,
                        "back": back,
                        "detail": detail,
                        "dist": dist,
                        "hotspot": hotspot,
                        "max_results": max_results,
                        "spp_locale": spp_locale,
                    },
                    notable_list_params.NotableListParams,
                ),
            ),
            cast_to=NotableListResponse,
        )


class NotableResourceWithRawResponse:
    def __init__(self, notable: NotableResource) -> None:
        self._notable = notable

        self.list = to_raw_response_wrapper(
            notable.list,
        )


class AsyncNotableResourceWithRawResponse:
    def __init__(self, notable: AsyncNotableResource) -> None:
        self._notable = notable

        self.list = async_to_raw_response_wrapper(
            notable.list,
        )


class NotableResourceWithStreamingResponse:
    def __init__(self, notable: NotableResource) -> None:
        self._notable = notable

        self.list = to_streamed_response_wrapper(
            notable.list,
        )


class AsyncNotableResourceWithStreamingResponse:
    def __init__(self, notable: AsyncNotableResource) -> None:
        self._notable = notable

        self.list = async_to_streamed_response_wrapper(
            notable.list,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from .notable_list_params import NotableListParams as NotableListParams
from .historic_list_params import HistoricListParams as HistoricListParams
from .notable_list_response import NotableListResponse as NotableListResponse
from .historic_list_response import HistoricListResponse as HistoricListResponse
from .specie_retrieve_params import SpecieRetrieveParams as SpecieRetrieveParams
from .specie_retrieve_response import SpecieRetrieveResponse as SpecieRetrieveResponse



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Literal

import httpx

from ...._types import NOT_GIVEN, Body, Query, Headers, NotGiven
from ...._utils import maybe_transform, async_maybe_transform
from ...._compat import cached_property
from ...._resource import SyncAPIResource, AsyncAPIResource
from ...._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from ...._base_client import make_request_options
from ....types.ref.region import list_list_params
from ....types.ref.region.list_list_response import ListListResponse

__all__ = ["ListResource", "AsyncListResource"]


class ListResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> ListResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/phoebe-bird/phoebe-python#accessing-raw-response-data-eg-headers
        """
        return ListResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> ListResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/phoebe-bird/phoebe-python#with_streaming_response
        """
        return ListResourceWithStreamingResponse(self)

    def list(
        self,
        parent_region_code: str,
        *,
        region_type: str,
        fmt: Literal["csv", "json"] | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> ListListResponse:
        """Get the list of sub-regions for a given country or region.

        #### Notes Not all
        combinations of region type and region code are valid. You can fetch all the
        subnational1 or subnational2 regions for a country however you can only specify
        a region type of 'country' when using 'world' as a region code.

        Args:
          fmt: Fetch the records in CSV or JSON format.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not region_type:
            raise ValueError(f"Expected a non-empty value for `region_type` but received {region_type!r}")
        if not parent_region_code:
            raise ValueError(f"Expected a non-empty value for `parent_region_code` but received {parent_region_code!r}")
        return self._get(
            f"/ref/region/list/{region_type}/{parent_region_code}",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform({"fmt": fmt}, list_list_params.ListListParams),
            ),
            cast_to=ListListResponse,
        )


class AsyncListResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncListResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/phoebe-bird/phoebe-python#accessing-raw-response-data-eg-headers
        """
        return AsyncListResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncListResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/phoebe-bird/phoebe-python#with_streaming_response
        """
        return AsyncListResourceWithStreamingResponse(self)

    async def list(
        self,
        parent_region_code: str,
        *,
        region_type: str,
        fmt: Literal["csv", "json"] | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> ListListResponse:
        """Get the list of sub-regions for a given country or region.

        #### Notes Not all
        combinations of region type and region code are valid. You can fetch all the
        subnational1 or subnational2 regions for a country however you can only specify
        a region type of 'country' when using 'world' as a region code.

        Args:
          fmt: Fetch the records in CSV or JSON format.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not region_type:
            raise ValueError(f"Expected a non-empty value for `region_type` but received {region_type!r}")
        if not parent_region_code:
            raise ValueError(f"Expected a non-empty value for `parent_region_code` but received {parent_region_code!r}")
        return await self._get(
            f"/ref/region/list/{region_type}/{parent_region_code}",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=await async_maybe_transform({"fmt": fmt}, list_list_params.ListListParams),
            ),
            cast_to=ListListResponse,
        )


class ListResourceWithRawResponse:
    def __init__(self, list: ListResource) -> None:
        self._list = list

        self.list = to_raw_response_wrapper(
            list.list,
        )


class AsyncListResourceWithRawResponse:
    def __init__(self, list: AsyncListResource) -> None:
        self._list = list

        self.list = async_to_raw_response_wrapper(
            list.list,
        )


class ListResourceWithStreamingResponse:
    def __init__(self, list: ListResource) -> None:
        self._list = list

        self.list = to_streamed_response_wrapper(
            list.list,
        )


class AsyncListResourceWithStreamingResponse:
    def __init__(self, list: AsyncListResource) -> None:
        self._list = list

        self.list = async_to_streamed_response_wrapper(
            list.list,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional
from typing_extensions import TypeAlias

from pydantic import Field as FieldInfo

from ...._models import BaseModel

__all__ = ["LocaleListResponse", "LocaleListResponseItem"]


class LocaleListResponseItem(BaseModel):
    code: Optional[str] = None

    last_updated: Optional[str] = FieldInfo(alias="lastUpdated", default=None)

    name: Optional[str] = None


LocaleListResponse: TypeAlias = List[LocaleListResponseItem]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from .info import (
    InfoResource,
    AsyncInfoResource,
    InfoResourceWithRawResponse,
    AsyncInfoResourceWithRawResponse,
    InfoResourceWithStreamingResponse,
    AsyncInfoResourceWithStreamingResponse,
)
from .list import (
    ListResource,
    AsyncListResource,
    ListResourceWithRawResponse,
    AsyncListResourceWithRawResponse,
    ListResourceWithStreamingResponse,
    AsyncListResourceWithStreamingResponse,
)
from .adjacent import (
    AdjacentResource,
    AsyncAdjacentResource,
    AdjacentResourceWithRawResponse,
    AsyncAdjacentResourceWithRawResponse,
    AdjacentResourceWithStreamingResponse,
    AsyncAdjacentResourceWithStreamingResponse,
)
from ...._compat import cached_property
from ...._resource import SyncAPIResource, AsyncAPIResource

__all__ = ["RegionResource", "AsyncRegionResource"]


class RegionResource(SyncAPIResource):
    @cached_property
    def adjacent(self) -> AdjacentResource:
        return AdjacentResource(self._client)

    @cached_property
    def info(self) -> InfoResource:
        return InfoResource(self._client)

    @cached_property
    def list(self) -> ListResource:
        return ListResource(self._client)

    @cached_property
    def with_raw_response(self) -> RegionResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/phoebe-bird/phoebe-python#accessing-raw-response-data-eg-headers
        """
        return RegionResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> RegionResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/phoebe-bird/phoebe-python#with_streaming_response
        """
        return RegionResourceWithStreamingResponse(self)


class AsyncRegionResource(AsyncAPIResource):
    @cached_property
    def adjacent(self) -> AsyncAdjacentResource:
        return AsyncAdjacentResource(self._client)

    @cached_property
    def info(self) -> AsyncInfoResource:
        return AsyncInfoResource(self._client)

    @cached_property
    def list(self) -> AsyncListResource:
        return AsyncListResource(self._client)

    @cached_property
    def with_raw_response(self) -> AsyncRegionResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/phoebe-bird/phoebe-python#accessing-raw-response-data-eg-headers
        """
        return AsyncRegionResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncRegionResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/phoebe-bird/phoebe-python#with_streaming_response
        """
        return AsyncRegionResourceWithStreamingResponse(self)


class RegionResourceWithRawResponse:
    def __init__(self, region: RegionResource) -> None:
        self._region = region

    @cached_property
    def adjacent(self) -> AdjacentResourceWithRawResponse:
        return AdjacentResourceWithRawResponse(self._region.adjacent)

    @cached_property
    def info(self) -> InfoResourceWithRawResponse:
        return InfoResourceWithRawResponse(self._region.info)

    @cached_property
    def list(self) -> ListResourceWithRawResponse:
        return ListResourceWithRawResponse(self._region.list)


class AsyncRegionResourceWithRawResponse:
    def __init__(self, region: AsyncRegionResource) -> None:
        self._region = region

    @cached_property
    def adjacent(self) -> AsyncAdjacentResourceWithRawResponse:
        return AsyncAdjacentResourceWithRawResponse(self._region.adjacent)

    @cached_property
    def info(self) -> AsyncInfoResourceWithRawResponse:
        return AsyncInfoResourceWithRawResponse(self._region.info)

    @cached_property
    def list(self) -> AsyncListResourceWithRawResponse:
        return AsyncListResourceWithRawResponse(self._region.list)


class RegionResourceWithStreamingResponse:
    def __init__(self, region: RegionResource) -> None:
        self._region = region

    @cached_property
    def adjacent(self) -> AdjacentResourceWithStreamingResponse:
        return AdjacentResourceWithStreamingResponse(self._region.adjacent)

    @cached_property
    def info(self) -> InfoResourceWithStreamingResponse:
        return InfoResourceWithStreamingResponse(self._region.info)

    @cached_property
    def list(self) -> ListResourceWithStreamingResponse:
        return ListResourceWithStreamingResponse(self._region.list)


class AsyncRegionResourceWithStreamingResponse:
    def __init__(self, region: AsyncRegionResource) -> None:
        self._region = region

    @cached_property
    def adjacent(self) -> AsyncAdjacentResourceWithStreamingResponse:
        return AsyncAdjacentResourceWithStreamingResponse(self._region.adjacent)

    @cached_property
    def info(self) -> AsyncInfoResourceWithStreamingResponse:
        return AsyncInfoResourceWithStreamingResponse(self._region.info)

    @cached_property
    def list(self) -> AsyncListResourceWithStreamingResponse:
        return AsyncListResourceWithStreamingResponse(self._region.list)
